Yog.FSharp
Getting Started Examples API Reference GitHub

MaxFlowResult<'e> Type

Result of a max flow computation.

Contains both the maximum flow value and information needed to extract the minimum cut.

Type Parameters

  • 'e: The flow/capacity type (int, float, etc.)

Record fields

Record Field Description

MaxFlow

Full Usage: MaxFlow

Field type: 'e

The maximum flow value from source to sink.

Field type: 'e

ResidualGraph

Full Usage: ResidualGraph

Field type: Graph<unit, 'e>

The residual graph after flow computation (contains remaining capacities). Edges with positive residual capacity can admit more flow.

Field type: Graph<unit, 'e>

Sink

Full Usage: Sink

Field type: NodeId

The sink node used in the computation.

Field type: NodeId

Full Usage: Source

Field type: NodeId

The source node used in the computation.

Field type: NodeId