Yog.FSharp
Getting Started Examples API Reference GitHub

MinCut Type

Represents a minimum cut in the network.

A cut partitions the nodes into two sets: those reachable from the source in the residual graph (source side) and the rest (sink side).

Key Property

The capacity of this cut equals the maximum flow value (max-flow min-cut theorem).

Record fields

Record Field Description

SinkSide

Full Usage: SinkSide

Field type: Set<NodeId>

Nodes NOT reachable from source in the residual graph (sink side of cut).

Field type: Set<NodeId>

SourceSide

Full Usage: SourceSide

Field type: Set<NodeId>

Nodes reachable from source in the residual graph (source side of cut).

Field type: Set<NodeId>