Yog.FSharp
Getting Started Examples API Reference GitHub

Utils Module

Utility types for pathfinding algorithms.

Provides the Path<'e> type which represents a computed path through a graph along with its total weight/cost.

Types

Type Description

Path<'e>

Represents a computed path through a graph along with its total weight.