Dag<'n, 'e> Type
The 'internal' constructor allows the Model and Algorithms modules to create Dags, but prevents external users from bypassing the guard.
Type Parameters
'n: Node data type (must support equality)'e: Edge weight type (must support equality)