Utils Module
Utility types for pathfinding algorithms.
Provides the Path<'e> type which represents a computed path through a graph
along with its total weight/cost.
Types
| Type | Description |
|
Represents a computed path through a graph along with its total weight. |